sign_in_js: Sign in and register pages JavaScript dependencies
Description
This function should be called at the bottom of your custom sign in and registration
pages UI. It loads in all the JavaScript dependencies to handle polished sign
in and registration. See the vignette for details.
Usage
sign_in_js(ns)
Arguments
ns
the ns function from the Shiny module that this function is called
within.