Learn R Programming

polished (version 0.1.0)

sign_in_no_invite_module_ui: Generates sign in page that does not require user invites

Description

UI for the sign in and registration pages. sign_in_no_invite_module does not require your users to be invited to your 'shiny' app before registering and signing in. i.e. if you use sign_in_no_invite_module, anyone will be able to register and sign in to access your 'shiny' app. See sign_in_module if you wish to limit access to only invited users.

Usage

sign_in_no_invite_module_ui(id)

Arguments

id

the Shiny module id