Returns the leading length characters of the normalised EPID
(trimmed, whitespace-collapsed, upper-cased) – the country+province+
district stem used to recover geography from sibling records.
Examples
epid_prefix(c("NIE-BOS-XYZ-24-001", NA))
#> [1] "NIE-BOS-XYZ" NA