Rewrites the epid column using a synonym table (old EPID -> canonical EPID)
so that records POLIS has merged collapse together in the subsequent
polis_upsert() step. A no-op when synonyms is NULL, so cleaners can call
it unconditionally.
Rewrites the epid column using a synonym table (old EPID -> canonical EPID)
so that records POLIS has merged collapse together in the subsequent
polis_upsert() step. A no-op when synonyms is NULL, so cleaners can call
it unconditionally.