UI for the sign in and register pages when a user invite is required to register and
sign in. See sign_in_no_invite_module if you do not require your
users to sign in and register to access your 'shiny' app.
sign_in_module_ui(id, register_link = "First time user? Register here!")the Shiny module id
The text that will be displayed in the link to go to the
user registration page. The default is "First time user? Register here!".
Set to NULL if you don't want to use the registration page.